@@ -7,7 +7,6 @@
 #' @inheritParams nameDoc
 #' @inheritParams cohortIdSubsetDoc
 #' @param n Number of times to duplicate the selected cohorts.
-#' @inheritParams softValidationDoc
 #'
 #' @return A new cohort table containing cohorts from the original cohort table.
 #' @export
@@ -15,17 +14,18 @@
 #' @examples
 #' \donttest{
 #' library(CohortConstructor)
+#' if(isTRUE(omock::isMockDatasetDownloaded("GiBleed"))){
 #' cdm <- mockCohortConstructor()
 #' cdm$cohort3 <- copyCohorts(cdm$cohort1, n = 2, cohortId = 1, name = "cohort3")
-#'}
-copyCohorts <- function(cohort, name, n = 1, cohortId = NULL, .softValidation = TRUE) {
+#' }
+#' }
+copyCohorts <- function(cohort, name, n = 1, cohortId = NULL) {
   omopgenerics::validateCohortArgument(cohort)
   cdm <- omopgenerics::cdmReference(cohort)
   omopgenerics::validateNameArgument(name, cdm = cdm, validation = "warning")
   omopgenerics::assertNumeric(x = n, integerish = TRUE, min = 1, length = 1)
   if (is.infinite(n)) cli::cli_abort("`n` cannot be infinite.")
   cohortId <- omopgenerics::validateCohortIdArgument(cohortId, cohort = cohort)
-  omopgenerics::assertLogical(.softValidation)
 
   # subset cohort
   if (isFALSE(needsIdFilter(cohort = cohort, cohortId = cohortId))){
@@ -34,7 +34,7 @@ copyCohorts <- function(cohort, name, n = 1, cohortId = NULL, .softValidation =
                      logPrefix = "CohortConstructor_copyCohors_subset_")
   } else {
     newCohort <- cohort |>
-      CohortConstructor::subsetCohorts(cohortId = cohortId, name = name, .softValidation = .softValidation)
+      CohortConstructor::subsetCohorts(cohortId = cohortId, name = name)
   }
 
   # duplicate
@@ -50,7 +50,7 @@ copyCohorts <- function(cohort, name, n = 1, cohortId = NULL, .softValidation =
         cohortSetRef = set,
         cohortAttritionRef = att,
         cohortCodelistRef = codes,
-        .softValidation = .softValidation
+        .softValidation = TRUE
       )
   }
 
