@@ -18,22 +18,27 @@
 #' @examples
 #' \donttest{
 #' library(CohortConstructor)
-#' cdm <- mockCohortConstructor(tables = list(
-#' "cohort" = dplyr::tibble(
-#'   cohort_definition_id = 1,
-#'   subject_id = c(1, 2, 3, 4),
-#'   cohort_start_date = as.Date(c("2000-06-03", "2000-01-01", "2015-01-15", "2000-12-09")),
-#'   cohort_end_date = as.Date(c("2001-09-01", "2001-01-12", "2015-02-15", "2002-12-09")),
-#'   date_1 = as.Date(c("2001-08-01", "2001-01-01", "2015-01-15", "2002-12-09")),
-#'   date_2 = as.Date(c("2001-08-01", NA, "2015-02-14", "2002-12-09"))
-#' )
-#' ))
-#' cdm$cohort |> entryAtLastDate(dateColumns = c("date_1", "date_2"))
+#' library(PatientProfiles)
+#' if(isTRUE(omock::isMockDatasetDownloaded("GiBleed"))){
+#' cdm <- mockCohortConstructor()
+#'
+#' cdm$cohort1 <- cdm$cohort1 |>
+#'   addTableIntersectDate(
+#'     tableName = "drug_exposure",
+#'     nameStyle = "prior_drug",
+#'     order = "last",
+#'     window = c(-Inf, 0)
+#'   ) |>
+#'   addPriorObservation(priorObservationType = "date", name = "cohort1")
+#'
+#' cdm$cohort1 |>
+#'   entryAtFirstDate(dateColumns = c("prior_drug", "prior_observation"))
+#' }
 #' }
 entryAtFirstDate <- function(cohort,
                              dateColumns,
                              cohortId = NULL,
-                             returnReason = TRUE,
+                             returnReason = FALSE,
                              keepDateColumns = TRUE,
                              name = tableName(cohort),
                              .softValidation = FALSE) {
@@ -70,23 +75,29 @@ entryAtFirstDate <- function(cohort,
 #'
 #' @examples
 #' \donttest{
+#' if(isTRUE(omock::isMockDatasetDownloaded("GiBleed"))){
 #' library(CohortConstructor)
-#' cdm <- mockCohortConstructor(tables = list(
-#' "cohort" = dplyr::tibble(
-#'   cohort_definition_id = 1,
-#'   subject_id = c(1, 2, 3, 4),
-#'   cohort_start_date = as.Date(c("2000-06-03", "2000-01-01", "2015-01-15", "2000-12-09")),
-#'   cohort_end_date = as.Date(c("2001-09-01", "2001-01-12", "2015-02-15", "2002-12-09")),
-#'   date_1 = as.Date(c("2001-08-01", "2001-01-01", "2015-01-15", "2002-12-09")),
-#'   date_2 = as.Date(c("2001-08-01", NA, "2015-02-14", "2002-12-09"))
-#' )
-#' ))
-#' cdm$cohort |> entryAtLastDate(dateColumns = c("date_1", "date_2"))
+#' library(PatientProfiles)
+#'
+#' cdm <- mockCohortConstructor()
+#'
+#' cdm$cohort1 <- cdm$cohort1 |>
+#'   addTableIntersectDate(
+#'     tableName = "drug_exposure",
+#'     nameStyle = "prior_drug",
+#'     order = "last",
+#'     window = c(-Inf, 0)
+#'   ) |>
+#'   addPriorObservation(priorObservationType = "date", name = "cohort1")
+#'
+#' cdm$cohort1 |>
+#'   entryAtLastDate(dateColumns = c("prior_drug", "prior_observation"))
+#' }
 #' }
 entryAtLastDate <- function(cohort,
                             dateColumns,
                             cohortId = NULL,
-                            returnReason = TRUE,
+                            returnReason = FALSE,
                             keepDateColumns = TRUE,
                             name = tableName(cohort),
                             .softValidation = FALSE) {
