@@ -22,16 +22,13 @@
 #' @examples
 #' \donttest{
 #' library(CohortConstructor)
+#' if(isTRUE(omock::isMockDatasetDownloaded("GiBleed"))){
+#' cdm <- mockCohortConstructor()
 #'
-#' cdm <- mockCohortConstructor(nPerson = 100)
-#'
-#' cdm$cohort3 <- intersectCohorts(
-#'   cohort = cdm$cohort2,
-#'   name = "cohort3",
-#' )
+#' cdm$cohort3 <- intersectCohorts(cohort = cdm$cohort2, name = "cohort3")
 #'
 #' settings(cdm$cohort3)
-#'
+#' }
 #' }
 intersectCohorts <- function(cohort,
                              cohortId = NULL,
@@ -67,8 +64,7 @@ intersectCohorts <- function(cohort,
   tblName <- omopgenerics::uniqueTableName(prefix = tablePrefix)
   newCohort <- copyCohorts(cohort,
                            name = tblName,
-                           cohortId = cohortId,
-                           .softValidation = .softValidation)
+                           cohortId = cohortId)
   # get intersections between cohorts
   lowerWindow <- ifelse(gap != 0, -gap, gap)
   newCohort <- newCohort |>
@@ -220,7 +216,7 @@ intersectCohorts <- function(cohort,
     )
   }
 
-  CDMConnector::dropTable(cdm, name = dplyr::starts_with(tablePrefix))
+  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::starts_with(tablePrefix))
 
   useIndexes <- getOption("CohortConstructor.use_indexes")
   if (!isFALSE(useIndexes)) {
@@ -253,20 +249,10 @@ splitOverlap <- function(x,
                          end = "cohort_end_date",
                          by = c("cohort_definition_id", "subject_id")) {
   # initial checks
-  checkmate::assertCharacter(start,
-                             len = 1,
-                             min.chars = 1,
-                             any.missing = FALSE)
-  checkmate::assertCharacter(end,
-                             len = 1,
-                             min.chars = 1,
-                             any.missing = FALSE)
-  checkmate::assertCharacter(by,
-                             min.len = 1,
-                             min.chars = 1,
-                             any.missing = FALSE)
-  checkmate::assertClass(x, "tbl")
-  checkmate::assertTRUE(all(c(start, end, by) %in% colnames(x)))
+  omopgenerics::assertCharacter(start, length = 1, minNumCharacter = 1)
+  omopgenerics::assertCharacter(end, length = 1, minNumCharacter = 1)
+  omopgenerics::assertCharacter(by, length = 1, minNumCharacter = 1)
+  omopgenerics::assertTable(x, class = "tbl", columns = c(start, end, by))
 
   ids <- getIdentifier(x, 3)
   id <- ids[1]
@@ -288,9 +274,9 @@ splitOverlap <- function(x,
   tmpTable_2 <- paste0(tmp, "_2")
   x_a <-  x_a |>
     dplyr::group_by(dplyr::across(dplyr::all_of(by))) |>
-    dbplyr::window_order(.data[[is]]) |>
+    dplyr::arrange(.data[[is]]) |>
     dplyr::mutate(!!id := dplyr::row_number()) |>
-    dbplyr::window_order() |>
+    dplyr::arrange() |>
     dplyr::ungroup() |>
     dplyr::compute(temporary = FALSE, name = tmpTable_2,
                    logPrefix = "CohortConstructor_intersectCohorts_tmpTable_2_")
@@ -305,9 +291,9 @@ splitOverlap <- function(x,
     ) |>
     dplyr::distinct() |>
     dplyr::group_by(dplyr::across(dplyr::all_of(by))) |>
-    dbplyr::window_order(.data[[ie]]) |>
+    dplyr::arrange(.data[[ie]]) |>
     dplyr::mutate(!!id := dplyr::row_number() - 1) |>
-    dbplyr::window_order() |>
+    dplyr::arrange() |>
     dplyr::ungroup() |>
     dplyr::compute(temporary = FALSE, name = tmpTable_3,
                    logPrefix = "CohortConstructor_intersectCohorts_tmpTable_3_")
@@ -458,17 +444,6 @@ getIdentifier <- function(x,
                           len = 1,
                           prefix = "",
                           nchar = 5) {
-  checkmate::assertClass(x, "tbl")
-  checkmate::assertIntegerish(len,
-                              lower = 1,
-                              len = 1,
-                              any.missing = FALSE)
-  checkmate::assertCharacter(prefix, any.missing = FALSE, len = 1)
-  checkmate::assertIntegerish(nchar,
-                              len = 1,
-                              lower = 1,
-                              any.missing = FALSE)
-
   cols <- colnames(x)
 
   x <- character()
