@@ -11,7 +11,17 @@
 #' @inheritParams windowDoc
 #' @inheritParams nameDoc
 #' @inheritParams atFirstDoc
-#' @inheritParams softValidationDoc
+#' @param cohortCombinationCriteria Can be 'all', 'any, or a numeric vector
+#' (length 1 or 2) that specifies how many of the target cohorts must meet the
+#' intersection requirement.
+#'
+#' Examples:
+#' - 'all': must meet criteria for each of the target cohorts.
+#' - 'any': must meet criteria for only one of the target cohorts.
+#' - Single value: e.g., `4`, exactly 4 cohorts must meet the criteria. If
+#' there were 4 target cohorts, this would be the same as 'all'.
+#' - Range: e.g., `c(2, Inf)`, must meet criteria at last 2 of the
+#' target cohorts. Note, `c(1, Inf)` is equivalent to 'any'.
 #'
 #' @return Cohort table with only those entries satisfying the criteria
 #'
@@ -20,6 +30,7 @@
 #' @examples
 #' \donttest{
 #' library(CohortConstructor)
+#' if(isTRUE(omock::isMockDatasetDownloaded("GiBleed"))){
 #' cdm <- mockCohortConstructor()
 #' cdm$cohort1 |>
 #'   requireCohortIntersect(targetCohortTable = "cohort2",
@@ -27,23 +38,24 @@
 #'                          indexDate = "cohort_start_date",
 #'                          window = c(-Inf, 0))
 #' }
+#' }
 requireCohortIntersect <- function(cohort,
                                    targetCohortTable,
                                    window,
                                    intersections = c(1, Inf),
                                    cohortId = NULL,
                                    targetCohortId = NULL,
+                                   cohortCombinationCriteria = "all",
                                    indexDate = "cohort_start_date",
                                    targetStartDate = "cohort_start_date",
                                    targetEndDate = "cohort_end_date",
                                    censorDate = NULL,
                                    atFirst = FALSE,
-                                   name = tableName(cohort),
-                                   .softValidation = TRUE) {
+                                   name = tableName(cohort)) {
   # checks
   name <- omopgenerics::validateNameArgument(name, validation = "warning")
   cohort <- omopgenerics::validateCohortArgument(cohort)
-  validateCohortColumn(indexDate, cohort, class = "Date")
+  validateCohortColumn(indexDate, cohort, class = "date")
   cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
   omopgenerics::validateCohortArgument(cdm[[targetCohortTable]])
   window <- omopgenerics::validateWindowArgument(window)
@@ -54,7 +66,10 @@ requireCohortIntersect <- function(cohort,
     {{targetCohortId}}, cdm[[targetCohortTable]], validation = "error"
   )
   intersections <- validateIntersections(intersections)
-  omopgenerics::assertLogical(.softValidation, length = 1)
+  cohortCombinationCriteria <- validateIntersections(cohortCombinationCriteria,
+                                                     name = "cohortCombinationCriteria",
+                                                     targetCohort = cdm[[targetCohortTable]],
+                                                     targetCohortId = targetCohortId)
   omopgenerics::assertLogical(atFirst, length = 1)
 
   if (length(cohortId) == 0) {
@@ -65,34 +80,33 @@ requireCohortIntersect <- function(cohort,
     return(cdm[[name]])
   }
 
-  if (cdm[[targetCohortTable]] |>
-      dplyr::filter(.data$cohort_definition_id %in% .env$targetCohortId) |>
-      dplyr::tally() |>
-      dplyr::pull("n") == 0) {
-    cli::cli_inform("Returning entry cohort as the target cohort to intersect is empty.")
-    # return entry cohort as cohortId is used to modify not subset
-    cdm[[name]] <- cohort |> dplyr::compute(name = name, temporary = FALSE,
-                                            logPrefix = "CohortConstructor_requireCohortIntersect_entry_2_")
-    return(cdm[[name]])
-  }
-
-  # targetCohortId must be singular
-  if (length(targetCohortId) > 1) {
-    cli::cli_abort(c("requireCohortIntersect can only be use with one target cohort at a time.",
-                     "i" = "Cohort IDs {targetCohortId} found in targetCohortTable {targetCohortTable}",
-                     "i" = "Use targetCohortId argument to specify just one cohort for intersection"))
-  }
-
+  # Fix ranges
   lower_limit <- as.integer(intersections[[1]])
   upper_limit <- intersections[[2]]
   upper_limit[is.infinite(upper_limit)] <- 999999L
-  upper_limit <- as.integer(upper_limit)
+
+  combinations_lower_limit <- as.integer(cohortCombinationCriteria[[1]])
+  combinations_upper_limit <- cohortCombinationCriteria[[2]]
+  combinations_upper_limit[is.infinite(combinations_upper_limit)] <- 999999L
 
   window_start <- window[[1]][1]
   window_end <- window[[1]][2]
 
+  # Check if the target cohort is empty for the specified targetCohortId
+  targetCohortCount <- cdm[[targetCohortTable]] |>
+    dplyr::filter(.data$cohort_definition_id %in% .env$targetCohortId) |>
+    dplyr::tally() |>
+    dplyr::pull("n")
+  if (targetCohortCount == 0) {
+    if (lower_limit == 0) {
+      cli::cli_inform("Target cohort is empty. No subjects will be excluded from the result.")
+    } else {
+      cli::cli_inform("Target cohort is empty. All subjects will be excluded from the result.")
+    }
+  }
+
   if (length(targetCohortTable) > 1) {
-    cli::cli_abort("Only one target cohort table is currently supported")
+    cli::cli_abort("Only one target cohort table is supported")
   }
 
   if (is.null(targetCohortId)) {
@@ -100,13 +114,9 @@ requireCohortIntersect <- function(cohort,
       dplyr::pull("cohort_definition_id")
   }
 
-  if (length(targetCohortId) > 1) {
-    cli::cli_abort("Only one target cohort ID is currently supported")
-  }
-
   target_name <- cdm[[targetCohortTable]] |>
     omopgenerics::settings() |>
-    dplyr::filter(.data$cohort_definition_id == .env$targetCohortId) |>
+    dplyr::filter(.data$cohort_definition_id %in% .env$targetCohortId) |>
     dplyr::pull("cohort_name")
 
   # temp tables
@@ -117,7 +127,6 @@ requireCohortIntersect <- function(cohort,
   newCohort <- cdm[[tmpNewCohort]]
 
   # requirement
-  intersectCol <- uniqueColumnName(newCohort)
   newCohort <- newCohort |>
     PatientProfiles::addCohortIntersectCount(
       targetCohortTable = targetCohortTable,
@@ -127,34 +136,24 @@ requireCohortIntersect <- function(cohort,
       targetEndDate = targetEndDate,
       window = window,
       censorDate = censorDate,
-      nameStyle = intersectCol,
+      nameStyle = "intersect_{cohort_name}",
       name = tmpNewCohort
     )
 
-  newCohort <- applyRequirement(
-    newCohort, atFirst, tmpNewCohort, intersectCol, lower_limit, upper_limit, cdm
+  intersectCols <- settings(cdm[[targetCohortTable]]) |>
+    dplyr::filter(.data$cohort_definition_id %in% .env$targetCohortId) |>
+    dplyr::pull("cohort_name")
+  intersectCols <- paste0("intersect_", intersectCols)
+
+  newCohort <- applyCohortRequirement(
+    cdm, newCohort, tmpNewCohort, atFirst, lower_limit, upper_limit, intersectCols, combinations_lower_limit, combinations_upper_limit
   )
 
   # attrition reason
-  if (all(intersections == 0)) {
-    reason <- glue::glue(
-      "Not in cohort {target_name} between {window_start} & ",
-      "{window_end} days relative to {indexDate}"
-    )
-  } else if (intersections[[1]] != intersections[[2]]) {
-    reason <- glue::glue(
-      "In cohort {target_name} between {window_start} & ",
-      "{window_end} days relative to {indexDate} between ",
-      "{intersections[[1]]} and {intersections[[2]]} times"
-    )
-  } else {
-    reason <- glue::glue(
-      "In cohort {target_name} between {window_start} & ",
-      "{window_end} days relative to {indexDate} ",
-      "{intersections[[1]]} times"
-    )
-  }
-  reason <- completeAttritionReason(reason, censorDate, atFirst)
+  reason <- createAttritionReason(
+    intersections, cohortCombinationCriteria, target_name, window_start, window_end,
+    indexDate, censorDate, atFirst
+  )
 
   # codelist
   targetCodelist <- attr(cdm[[targetCohortTable]], "cohort_codelist") |>
@@ -179,7 +178,7 @@ requireCohortIntersect <- function(cohort,
     dplyr::compute(name = name, temporary = FALSE,
                    logPrefix = "CohortConstructor_requireCohortIntersect_name_") |>
     omopgenerics::newCohortTable(
-      .softValidation = .softValidation, cohortCodelistRef = newCodelist
+      .softValidation = TRUE, cohortCodelistRef = newCodelist
     ) |>
     omopgenerics::recordCohortAttrition(reason = reason, cohortId = cohortId)
 
@@ -196,7 +195,8 @@ requireCohortIntersect <- function(cohort,
   return(newCohort)
 }
 
-applyRequirement <- function(newCohort, atFirst, tmpNewCohort, intersectCol, lower_limit, upper_limit, cdm) {
+applyCohortRequirement <- function(cdm, newCohort, tmpNewCohort, atFirst, lower_limit, upper_limit, intersectCols, combinations_lower_limit, combinations_upper_limit) {
+  mutateExpr <- getMutateFilterExpression(lower_limit, upper_limit, intersectCols)
   if (atFirst) {
     tmpNewCohortFirst <- paste0(tmpNewCohort, "_1")
     newCohortFirst <- newCohort |>
@@ -204,32 +204,87 @@ applyRequirement <- function(newCohort, atFirst, tmpNewCohort, intersectCol, low
       dplyr::filter(.data$cohort_start_date == base::min(.data$cohort_start_date)) |>
       dplyr::ungroup() |>
       dplyr::compute(name = tmpNewCohortFirst, temporary = FALSE,
-                     logPrefix = "CohortConstructor_applyRequirement_subset_arrange_") |>
-      dplyr::filter(
-        .data$rec_id_1234 == 1 & .data[[intersectCol]] >= .env$lower_limit & .data[[intersectCol]] <= .env$upper_limit
-        ) |>
+                     logPrefix = "CohortConstructor_applyCohortRequirement_subset_arrange_") |>
+      dplyr::mutate(!!!mutateExpr) |>
+      dplyr::filter(.data$cc_requirement_sum >= .env$combinations_lower_limit & .data$cc_requirement_sum <= .env$combinations_upper_limit) |>
       dplyr::select(dplyr::all_of(c("cohort_definition_id", "subject_id"))) |>
       dplyr::compute(name = tmpNewCohortFirst, temporary = FALSE,
-                     logPrefix = "CohortConstructor_applyRequirement_subset_first_")
+                     logPrefix = "CohortConstructor_applyCohortRequirement_subset_first_")
     newCohort <- newCohort |>
       dplyr::inner_join(newCohortFirst, by = c("cohort_definition_id", "subject_id")) |>
-      dplyr::select(!dplyr::all_of(intersectCol)) |>
+      dplyr::select(!dplyr::all_of(c(intersectCols))) |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE,
-                     logPrefix = "CohortConstructor_applyRequirement_requirement_first_")
+                     logPrefix = "CohortConstructor_applyCohortRequirement_requirement_first_")
     omopgenerics::dropSourceTable(cdm = cdm, name = tmpNewCohortFirst)
   } else {
     newCohort <- newCohort |>
-      dplyr::filter(
-        .data[[intersectCol]] >= .env$lower_limit & .data[[intersectCol]] <= .env$upper_limit
-      ) |>
-      dplyr::select(!dplyr::all_of(intersectCol)) |>
+      dplyr::mutate(!!!mutateExpr) |>
+      dplyr::filter(.data$cc_requirement_sum >= .env$combinations_lower_limit & .data$cc_requirement_sum <= .env$combinations_upper_limit) |>
+      dplyr::select(!dplyr::all_of(c(intersectCols, "cc_requirement_sum"))) |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE,
-                     logPrefix = "CohortConstructor_applyRequirement_subset_")
+                     logPrefix = "CohortConstructor_applyCohortRequirement_subset_")
   }
   return(newCohort)
 }
 
-completeAttritionReason <- function(reason, censorDate, atFirst) {
+getMutateFilterExpression <- function(lower_limit, upper_limit, intersectCols) {
+  mutateExpr <- NULL
+  for (col in intersectCols) {
+    mutateExpr <- c(mutateExpr, glue::glue("dplyr::if_else(.data${col} >= {lower_limit} & .data${col} <= {upper_limit}, 1L, 0L)"))
+  }
+  mutateExpr <- c(mutateExpr, glue::glue("{paste0('.data$', intersectCols, collapse = ' + ')}"))
+  mutateExpr |> rlang::parse_exprs() |> rlang::set_names(c(intersectCols, "cc_requirement_sum"))
+}
+
+formatRange <- function(x) {
+  x <- unique(x)
+  if (length(x) == 1) {
+    if (is.infinite(x)) return(paste0("any number of intersections"))
+    if (x == 1) return(paste0("1 intersection"))
+    return(paste0(x, " intersections"))
+  }
+  if (is.infinite(x[2])) return(paste0(x[1], " or more intersections"))
+  if (x[1] == x[2]) return(paste0(x[1], " intersections"))
+  paste0(x[1], " to ", x[2], " intersections")
+}
+
+formatCohortCombo <- function(x, n) {
+  x <- unique(x)
+  if (length(x) == 1) {
+    if (is.infinite(x)) return("any of the cohorts")
+    if (x == n) return(paste0("all ", n, " cohorts"))
+    return(paste0(x, " of the cohorts"))
+  }
+  if (is.infinite(x[2])) return(paste0(x[1], " or more of the cohorts"))
+  paste0(x[1], " to ", x[2], " of the cohorts")
+}
+
+createAttritionReason <- function(intersections,
+                                  cohortCombinationCriteria,
+                                  targetName,
+                                  windowStart,
+                                  windowEnd,
+                                  indexDate,
+                                  censorDate,
+                                  atFirst) {
+  if (length(targetName) > 1) {
+    reason <- paste0(
+      "Require ", formatRange(intersections),
+      " for ", formatCohortCombo(cohortCombinationCriteria, length(targetName)),
+      ": ", glue::glue_collapse(targetName, sep = ", ", last = " and "),
+      ". Intersection window: ", windowStart, " to ",
+      windowEnd, " days relative to ", indexDate
+    )
+  } else {
+    reason <- paste0(
+      "Require ", formatRange(intersections),
+      " with cohort ", targetName,
+      ". Intersection window: ", windowStart, " to ",
+      windowEnd, " days relative to ", indexDate
+    )
+  }
+
+
   if (!is.null(censorDate)) {
     reason <- glue::glue("{reason}, censoring at {censorDate}")
   }
