@@ -2,43 +2,42 @@ test_that("basic example", {
   skip_on_cran()
 
   observation_period <- dplyr::tibble(
-    observation_period_id = c(1, 2, 3, 4, 5,6),
-    person_id = c(1, 2, 3, 4, 5,6),
+    observation_period_id = c(1, 2, 3, 4, 5,6) |> as.integer(),
+    person_id = c(1, 2, 3, 4, 5,6)|> as.integer(),
     observation_period_start_date = c(
       rep(as.Date("1980-07-20"),6)
     ),
     observation_period_end_date = c(
       rep(as.Date("2023-05-20"),6)
     ),
-    period_type_concept_id = c(rep(0,6))
+    period_type_concept_id = c(rep(0,6)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = c(1,2,3),
+    person_id = c(1,2,3)|> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02"),
                    as.Date("2020-01-01")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
-  cdm_local <- omopgenerics::cdmFromTables(
+  cdm <- omopgenerics::cdmFromTables(
     tables = list(
       person = person,
       observation_period = observation_period,
       death = deathTable
     ),
     cdmName = "mock"
-  )
-
-  cdm <- cdm_local |> copyCdm()
+  ) |>
+    copyCdm()
 
   cdm$my_death_cohort <- deathCohort(cdm=cdm,
                                      name = "my_death_cohort")
@@ -53,42 +52,40 @@ test_that("basic example", {
   c("Initial qualifying events",
     "Record in observation",
     "Not missing record date",
-    "Non-missing sex",
-    "Non-missing year of birth",
     "First death record"))
 
-  CDMConnector::cdmDisconnect(cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("first death record per person", {
   skip_on_cran()
 
   observation_period <- dplyr::tibble(
-    observation_period_id = c(1, 2, 3, 4, 5,6),
-    person_id = c(1, 2, 3, 4, 5,6),
+    observation_period_id = c(1, 2, 3, 4, 5,6) |> as.integer(),
+    person_id = c(1, 2, 3, 4, 5,6) |> as.integer(),
     observation_period_start_date = c(
       rep(as.Date("1980-07-20"),6)
     ),
     observation_period_end_date = c(
       rep(as.Date("2023-05-20"),6)
     ),
-    period_type_concept_id = c(rep(0,6))
+    period_type_concept_id = c(rep(0,6)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = c(1,2,2),
+    person_id = c(1,2,2) |> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02"),
                    as.Date("2020-01-31")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
   cdm <- omopgenerics::cdmFromTables(
@@ -105,14 +102,14 @@ test_that("first death record per person", {
   cdm2$death_cohort <- deathCohort(cdm=cdm2,
                        name = "death_cohort")
 
-  expect_true(nrow(cdm2$death_cohort %>%
-                     dplyr::filter(subject_id == "2") %>%
+  expect_true(nrow(cdm2$death_cohort |>
+                     dplyr::filter(subject_id == "2") |>
                      dplyr::collect()) == 1)
 
 
-  expect_true(cdm2$death_cohort %>%
-                dplyr::filter(subject_id == "2") %>%
-                dplyr::select(cohort_start_date) %>%
+  expect_true(cdm2$death_cohort |>
+                dplyr::filter(subject_id == "2") |>
+                dplyr::select(cohort_start_date) |>
                 dplyr::pull() == as.Date("2020-01-02"))
 
   expect_identical(omopgenerics::attrition(cdm2$death_cohort) |>
@@ -125,15 +122,15 @@ test_that("first death record per person", {
                      dplyr::pull("excluded_subjects"),
                    0L)
 
-  CDMConnector::cdmDisconnect(cdm2)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test death in observation criteria", {
   skip_on_cran()
 
-  observation_period <- tibble::tibble(
-    observation_period_id = c(1, 2),
-    person_id = c(1,2),
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1, 2) |> as.integer(),
+    person_id = c(1,2) |> as.integer(),
     observation_period_start_date = c(
       as.Date("2000-01-01"),
       as.Date("2010-01-01")
@@ -142,22 +139,22 @@ test_that("test death in observation criteria", {
       as.Date("2005-01-01"),
       as.Date("2021-01-01")
     ),
-    period_type_concept_id = c(rep(0,2))
+    period_type_concept_id = c(rep(0,2)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = c(1,2),
+    person_id = c(1,2) |> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
   cdm <- omopgenerics::cdmFromTables(
@@ -174,25 +171,25 @@ test_that("test death in observation criteria", {
   cdm2$death_cohort <- deathCohort(cdm=cdm2,
                                  name = "death_cohort")
 
-  expect_true(nrow(cdm2$death_cohort %>% dplyr::collect()) == 1)
+  expect_true(nrow(cdm2$death_cohort |> dplyr::collect()) == 1)
 
-  expect_true(cdm2$death_cohort %>%
-                dplyr::select(subject_id) %>%
+  expect_true(cdm2$death_cohort |>
+                dplyr::select(subject_id) |>
                 dplyr::pull() == 2)
 
-  expect_true(cdm2$death_cohort %>%
-                dplyr::select(cohort_start_date) %>%
+  expect_true(cdm2$death_cohort |>
+                dplyr::select(cohort_start_date) |>
                 dplyr::pull() == as.Date("2020-01-02"))
 
-  CDMConnector::cdmDisconnect(cdm2)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test different cohort table name", {
   skip_on_cran()
 
-  observation_period <- tibble::tibble(
-    observation_period_id = c(1, 2, 3),
-    person_id = c(1,2, 3),
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1, 2, 3) |> as.integer(),
+    person_id = c(1,2, 3) |> as.integer(),
     observation_period_start_date = c(
       as.Date("2000-01-01"),
       as.Date("2010-01-01"),
@@ -203,23 +200,23 @@ test_that("test different cohort table name", {
       as.Date("2021-01-01"),
       as.Date("2022-01-01")
     ),
-    period_type_concept_id = c(rep(0,3))
+    period_type_concept_id = c(rep(0,3)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = c(1,2,3),
+    person_id = c(1,2,3) |> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02"),
                    as.Date("2020-01-01")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
   cdm <- omopgenerics::cdmFromTables(
@@ -241,15 +238,15 @@ test_that("test different cohort table name", {
                     "cohort_start_date", "cohort_end_date") %in%
                     colnames(cdm2$my_cohort_death)))
 
-  CDMConnector::cdmDisconnect(cdm2)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test subsetting death table by a cohort table", {
   skip_on_cran()
 
-  observation_period <- tibble::tibble(
-    observation_period_id = c(1, 2, 3),
-    person_id = c(1,2, 3),
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1, 2, 3) |> as.integer(),
+    person_id = c(1,2, 3) |> as.integer(),
     observation_period_start_date = c(
       as.Date("2000-01-01"),
       as.Date("2010-01-01"),
@@ -260,26 +257,26 @@ test_that("test subsetting death table by a cohort table", {
       as.Date("2021-01-01"),
       as.Date("2022-01-01")
     ),
-    period_type_concept_id = c(rep(0,3))
+    period_type_concept_id = c(rep(0,3)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = seq(1,5),
+    person_id = seq(1,5) |> as.integer(),
     death_date = c(as.Date("2020-01-01")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
-  cohort1 <- tibble::tibble(
-    cohort_definition_id = c(1,1,2),
-    subject_id = c(1,2,3),
+  cohort1 <- dplyr::tibble(
+    cohort_definition_id = c(1,1,2) |> as.integer(),
+    subject_id = c(1,2,3) |> as.integer(),
     cohort_start_date = as.Date(c("2012-02-01")),
     cohort_end_date = as.Date(c("2013-02-01"))
   )
@@ -302,10 +299,10 @@ test_that("test subsetting death table by a cohort table", {
                                  name = "death_cohort",
                                  subsetCohort = "cohort1")
 
-  expect_true(nrow(cdm2$death_cohort %>% dplyr::collect()) == 3)
+  expect_true(nrow(cdm2$death_cohort |> dplyr::collect()) == 3)
 
-  expect_true(all(cdm2$death_cohort %>%
-                    dplyr::select(subject_id) %>%
+  expect_true(all(cdm2$death_cohort |>
+                    dplyr::select(subject_id) |>
                     dplyr::pull() %in%  c(1,2,3)
   ))
   # with subsetCohortId
@@ -314,22 +311,22 @@ test_that("test subsetting death table by a cohort table", {
                        subsetCohort = "cohort1",
                        subsetCohortId = 1)
 
-  expect_true(nrow(cdm2$death_cohort %>% dplyr::collect()) == 2)
+  expect_true(nrow(cdm2$death_cohort |> dplyr::collect()) == 2)
 
-  expect_true(all(cdm2$death_cohort %>%
-                    dplyr::select(subject_id) %>%
+  expect_true(all(cdm2$death_cohort |>
+                    dplyr::select(subject_id) |>
                     dplyr::pull() %in%  c(1,2)
   ))
-  CDMConnector::cdmDisconnect(cdm2)
 
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test expected errors", {
   skip_on_cran()
 
-  observation_period <- tibble::tibble(
-    observation_period_id = c(1, 2, 3),
-    person_id = c(1,2, 3),
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1, 2, 3) |> as.integer(),
+    person_id = c(1,2, 3) |> as.integer(),
     observation_period_start_date = c(
       as.Date("2000-01-01"),
       as.Date("2010-01-01"),
@@ -340,22 +337,22 @@ test_that("test expected errors", {
       as.Date("2021-01-01"),
       as.Date("2022-01-01")
     ),
-    period_type_concept_id = c(rep(0,3))
+    period_type_concept_id = c(rep(0,3)) |> as.integer()
   )
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
-  cohort1 <- tibble::tibble(
-    cohort_definition_id = c(1,1,1),
-    subject_id = c(1,2,3),
+  cohort1 <- dplyr::tibble(
+    cohort_definition_id = c(1,1,1) |> as.integer(),
+    subject_id = c(1,2,3) |> as.integer(),
     cohort_start_date = as.Date(c("2012-02-01")),
     cohort_end_date = as.Date(c("2013-02-01"))
   )
@@ -371,15 +368,15 @@ test_that("test expected errors", {
     cdmName = "mock_es"
   )
 
-  cdm2 = copyCdm(cdm)
+  cdm = copyCdm(cdm)
 
   # no death table in CDM
-  expect_error(deathCohort(cdm=cdm2,
+  expect_error(deathCohort(cdm=cdm,
                            name = "death_cohort"))
 
   # cohortTable & cohortId
   deathTable <- dplyr::tibble(
-    person_id = c(1,2,3),
+    person_id = c(1,2,3) |> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02"),
                    as.Date("2020-01-01")))
@@ -397,28 +394,28 @@ test_that("test expected errors", {
     cdmName = "mock_es"
   )
 
-  cdm2 = copyCdm(cdm)
+  cdm = copyCdm(cdm)
 
   # cohortTable not exist
-  expect_error( deathCohort(cdm=cdm2,
+  expect_error( deathCohort(cdm=cdm,
                             name = "death_cohort",
                             subsetCohort = "non_exist_cohort"))
 
   # wrong cohortId input
-  expect_error(deathCohort(cdm=cdm2,
+  expect_error(deathCohort(cdm=cdm,
                            name = "death_cohort",
                            subsetCohort = "cohort1",
                            subsetCohortId = "1"))
 
-  CDMConnector::cdmDisconnect(cdm2)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test single permanent table created", {
   skip_on_cran()
 
-  observation_period <- tibble::tibble(
-    observation_period_id = c(1, 2, 3),
-    person_id = c(1,2, 3),
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1, 2, 3) |> as.integer(),
+    person_id = c(1,2, 3) |> as.integer(),
     observation_period_start_date = c(
       as.Date("2000-01-01"),
       as.Date("2010-01-01"),
@@ -429,23 +426,23 @@ test_that("test single permanent table created", {
       as.Date("2021-01-01"),
       as.Date("2022-01-01")
     ),
-    period_type_concept_id = c(rep(0,3))
+    period_type_concept_id = c(rep(0,3)) |> as.integer()
   )
 
   deathTable <- dplyr::tibble(
-    person_id = c(1,2,3),
+    person_id = c(1,2,3) |> as.integer(),
     death_date = c(as.Date("2020-01-01"),
                    as.Date("2020-01-02"),
                    as.Date("2021-01-01")))
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4, 5),
-    year_of_birth = c(rep(1990, 5)),
-    month_of_birth = c(rep(02, 5)),
-    day_of_birth = c(rep(11, 5)),
-    gender_concept_id = c(rep(0,5)),
-    ethnicity_concept_id = c(rep(0,5)),
-    race_concept_id = c(rep(0,5))
+    person_id = c(1, 2, 3, 4, 5) |> as.integer(),
+    year_of_birth = c(rep(1990, 5)) |> as.integer(),
+    month_of_birth = c(rep(02, 5)) |> as.integer(),
+    day_of_birth = c(rep(11, 5)) |> as.integer(),
+    gender_concept_id = c(rep(0,5)) |> as.integer(),
+    ethnicity_concept_id = c(rep(0,5)) |> as.integer(),
+    race_concept_id = c(rep(0,5)) |> as.integer()
   )
 
   cdm <- omopgenerics::cdmFromTables(
@@ -457,18 +454,17 @@ test_that("test single permanent table created", {
     cdmName = "mock_es"
   )
 
-  cdm2 = copyCdm(cdm)
+  cdm = copyCdm(cdm)
 
-  start_tables <- attr(cdm2, "names")
+  start_tables <- names(cdm)
 
-  cdm2$my_death_cohort <- deathCohort(cdm=cdm2,
-                                 name = "my_death_cohort")
+  cdm$my_death_cohort <- deathCohort(cdm=cdm, name = "my_death_cohort")
 
-  end_tables <- attr(cdm2, "names")
+  end_tables <- names(cdm)
 
-  testthat::expect_equal(
+  expect_equal(
     sort(end_tables),
     sort(c(start_tables, "my_death_cohort")))
 
-  CDMConnector::cdmDisconnect(cdm2)
+  dropCreatedTables(cdm = cdm)
 })
