@@ -1,8 +1,9 @@
 test_that("requiring presence in another table", {
-  testthat::skip_on_cran()
+  skip_on_cran()
+
   obs <- dplyr::tibble(
-    observation_period_id = c(1, 2, 3, 4),
-    person_id = c(1, 2, 3, 4),
+    observation_period_id = as.integer(c(1, 2, 3, 4)),
+    person_id = as.integer(c(1, 2, 3, 4)),
     observation_period_start_date = as.Date(c(
       "2000-06-03", "1999-04-05", "2015-01-15", "1989-12-09"
     )),
@@ -13,7 +14,7 @@ test_that("requiring presence in another table", {
   )
 
   person <- dplyr::tibble(
-    person_id = c(1, 2, 3, 4),
+    person_id = as.integer(c(1, 2, 3, 4)),
     gender_concept_id = c(8532, 8507, 8507, 8507),
     year_of_birth = c(1997, 1963, 1986, 1978),
     month_of_birth = c(8, 1, 3, 11),
@@ -24,7 +25,7 @@ test_that("requiring presence in another table", {
 
   cohort_1 <- dplyr::tibble(
     cohort_definition_id = c(1, 1, 1, 1, 2, 2, 2, 2),
-    subject_id = c(1, 1, 2, 3, 1, 1, 1, 1),
+    subject_id = as.integer(c(1, 1, 2, 3, 1, 1, 1, 1)),
     cohort_start_date = as.Date(c(
       "2003-05-17", "2004-03-11", "1999-05-03", "2015-02-25",
       "2001-03-24", "2001-11-28", "2002-01-30", "2002-06-13"
@@ -35,25 +36,15 @@ test_that("requiring presence in another table", {
     ))
   )
 
-  cdm_local <- omock::mockCdmFromTables(
-    tables = list(
-      "cohort1" = cohort_1
-    ),
-    seed = 1
-  )
-
-  cdm_local <- omopgenerics::insertTable(
-    cdm = cdm_local, name = "observation_period", table = obs)
-
-  cdm_local <- omopgenerics::insertTable(
-    cdm = cdm_local, name = "person", table = person)
-
-  cdm_local$table <- dplyr::tibble(
-    person_id = c(1, 3, 2, 2),
-    date_start = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01", "1999-01-01")),
-    date_end = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01", "1999-01-01"))
-  )
-  cdm <- cdm_local |> copyCdm()
+  cdm <- omock::mockCdmFromTables(tables = list("cohort1" = cohort_1)) |>
+    omopgenerics::insertTable(name = "observation_period", table = obs) |>
+    omopgenerics::insertTable(name = "person", table = person) |>
+    omopgenerics::insertTable(name = "table", table = dplyr::tibble(
+      person_id = as.integer(c(1, 3, 2, 2)),
+      date_start = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01", "1999-01-01")),
+      date_end = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01", "1999-01-01"))
+    )) |>
+    copyCdm()
 
   start_cols <- colnames(cdm$cohort1)
   cdm$cohort2 <-  requireTableIntersect(cohort = cdm$cohort1,
@@ -64,7 +55,6 @@ test_that("requiring presence in another table", {
                                         name = "cohort2")
   expect_identical(colnames(cdm$cohort2), colnames(cdm$cohort1))
 
-
   expect_identical(cdm$cohort2 |> dplyr::pull("subject_id") |> sort(), cdm$cohort1 |> dplyr::pull("subject_id") |> sort())
   expect_identical(omopgenerics::attrition(cdm$cohort2)$reason, c("Initial qualifying events",
                                                                   "In table table between -Inf & Inf days relative to cohort_start_date between 1 and Inf",
@@ -153,11 +143,12 @@ test_that("requiring presence in another table", {
                           window = c(-Inf, Inf))
   )
 
-  PatientProfiles::mockDisconnect(cdm)
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("requiring absence in another table", {
-  testthat::skip_on_cran
+  skip_on_cran()
+
   obs <- dplyr::tibble(
     observation_period_id = c(1, 2, 3, 4),
     person_id = c(1, 2, 3, 4),
@@ -193,25 +184,15 @@ test_that("requiring absence in another table", {
     ))
   )
 
-  cdm_local <- omock::mockCdmFromTables(
-    tables = list(
-      "cohort1" = cohort_1
-    ),
-    seed = 1
-  )
-
-  cdm_local <- omopgenerics::insertTable(
-    cdm = cdm_local, name = "observation_period", table = obs)
-
-  cdm_local <- omopgenerics::insertTable(
-    cdm = cdm_local, name = "person", table = person)
-
-  cdm_local$table <- dplyr::tibble(
-    person_id = c(1, 3, 4),
-    date_start = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01")),
-    date_end = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01"))
-  )
-  cdm <- cdm_local |> copyCdm()
+  cdm <- omock::mockCdmFromTables(tables = list("cohort1" = cohort_1)) |>
+    omopgenerics::insertTable(name = "observation_period", table = obs) |>
+    omopgenerics::insertTable(name = "person", table = person) |>
+    omopgenerics::insertTable(name = "table", table = dplyr::tibble(
+      person_id = c(1, 3, 4),
+      date_start = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01")),
+      date_end = as.Date(c("2002-01-01", "2015-10-01", "2000-01-01"))
+    )) |>
+    copyCdm()
 
   cdm$cohort2 <-  requireTableIntersect(cohort = cdm$cohort1,
                                         intersections = 0,
@@ -277,11 +258,12 @@ test_that("requiring absence in another table", {
                                                                   "Initial qualifying events"))
 
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  PatientProfiles::mockDisconnect(cdm)
+
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("different intersection count requirements", {
-  testthat::skip_on_cran()
+  skip_on_cran()
 
   cohort1 <- dplyr::tibble(
     subject_id = 1:10,
@@ -289,32 +271,32 @@ test_that("different intersection count requirements", {
     cohort_start_date = as.Date('2020-01-01'),
     cohort_end_date = as.Date('2020-01-01'))
 
-  cdm_local <- omock::mockCdmReference() |>
-    omock::mockCdmFromTables(tables = list("cohort1" = cohort1))
-
-  cdm_local$observation_period  <- cdm_local$observation_period |>
-    dplyr::mutate(observation_period_start_date = as.Date("2010-01-01"),
-                  observation_period_end_date = as.Date("2020-01-01"))
-
-  cdm_local$concept <- dplyr::tibble(
-    "concept_id" = 1,
-    "concept_name" = "my concept",
-    "domain_id" = "Drug",
-    "vocabulary_id" = NA,
-    "concept_class_id" = NA,
-    "concept_code" = NA,
-    "valid_start_date" = NA,
-    "valid_end_date" = NA
-  )
-  cdm_local$drug_exposure <- dplyr::tibble(
-    "drug_exposure_id" = 1:6,
-    "person_id" = c(1,2,2,3,3,3),
-    "drug_concept_id" = 1,
-    "drug_exposure_start_date" = as.Date('2019-01-01'),
-    "drug_exposure_end_date" = as.Date('2019-01-01'),
-    "drug_type_concept_id" = 1
-  )
-  cdm <- cdm_local |> copyCdm()
+  cdm <- omock::mockCdmReference() |>
+    omock::mockCdmFromTables(tables = list("cohort1" = cohort1)) |>
+    omock::mockVocabularyTables(concept = dplyr::tibble(
+      "concept_id" = 1,
+      "concept_name" = "my concept",
+      "domain_id" = "Drug",
+      "vocabulary_id" = NA,
+      "concept_class_id" = NA,
+      "concept_code" = NA,
+      "valid_start_date" = NA,
+      "valid_end_date" = NA
+    )) |>
+    omopgenerics::insertTable(name = "drug_exposure", table = dplyr::tibble(
+      "drug_exposure_id" = 1:6,
+      "person_id" = as.integer(c(1,2,2,3,3,3)),
+      "drug_concept_id" = 1,
+      "drug_exposure_start_date" = as.Date('2019-01-01'),
+      "drug_exposure_end_date" = as.Date('2019-01-01'),
+      "drug_type_concept_id" = 1
+    ))
+  cdm$observation_period <- cdm$observation_period |>
+    dplyr::mutate(
+      observation_period_start_date = as.Date("2010-01-01"),
+      observation_period_end_date = as.Date("2020-01-01")
+    )
+  cdm <- copyCdm(cdm = cdm)
 
   # no intersections - people not in cohort2
   expect_identical(sort(cdm$cohort1 |>
@@ -393,83 +375,76 @@ test_that("different intersection count requirements", {
                                      window = c(-Inf, Inf)))
 
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  PatientProfiles::mockDisconnect(cdm)
+
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test indexes - postgres, and atFirst", {
   skip_on_cran()
-  skip_if(Sys.getenv("CDM5_POSTGRESQL_DBNAME") == "")
   skip_if(!testIndexes)
 
-  db <- DBI::dbConnect(RPostgres::Postgres(),
-                       dbname = Sys.getenv("CDM5_POSTGRESQL_DBNAME"),
-                       host = Sys.getenv("CDM5_POSTGRESQL_HOST"),
-                       user = Sys.getenv("CDM5_POSTGRESQL_USER"),
-                       password = Sys.getenv("CDM5_POSTGRESQL_PASSWORD"))
-  cdm <- CDMConnector::cdmFromCon(
-    con = db,
-    cdmSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
-    writeSchema = Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
-    writePrefix = "cc_",
-    achillesSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
-  )
+  if (dbToTest == "postgres CDMConnector") {
+    cdm <- omock::mockCdmFromTables(tables = list(
+      my_cohort = dplyr::tibble(
+        cohort_definition_id = 1L,
+        subject_id = 1L,
+        cohort_start_date = as.Date("2009-01-02"),
+        cohort_end_date = as.Date("2009-01-03"),
+        other_date = as.Date("2009-01-01")
+      )
+    )) |>
+      copyCdm()
 
-  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::contains("og_"))
-  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::contains("my_cohort"))
+    con <- CDMConnector::cdmCon(cdm = cdm)
 
-  cdm <- omopgenerics::insertTable(cdm = cdm,
-                                   name = "my_cohort",
-                                   table = data.frame(cohort_definition_id = 1L,
-                                                      subject_id = 1L,
-                                                      cohort_start_date = as.Date("2009-01-02"),
-                                                      cohort_end_date = as.Date("2009-01-03"),
-                                                      other_date = as.Date("2009-01-01")))
-  cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort)
-  cdm$my_cohort <- requireTableIntersect(cdm$my_cohort, tableName = "visit_occurrence", window = list(c(-Inf, 0)))
-  expect_true(
-    DBI::dbGetQuery(db, paste0("SELECT * FROM pg_indexes WHERE tablename = 'cc_my_cohort';")) |> dplyr::pull("indexdef") ==
-      "CREATE INDEX cc_my_cohort_subject_id_cohort_start_date_idx ON public.cc_my_cohort USING btree (subject_id, cohort_start_date)"
-  )
+    omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::contains("og_"))
 
-  # atFirst
-  cohort <- dplyr::tibble(
-    cohort_definition_id = c(rep(1L, 4), rep(2L, 4)),
-    subject_id = c(1L, 1L, 2L, 3L, rep(1L, 4)),
-    cohort_start_date = as.Date(c(
-      "2008-01-01", "2009-03-11", "2010-05-03", "2010-02-25",
-      "2008-03-24", "2008-11-28", "2010-01-30", "2009-06-13"
-    )),
-    cohort_end_date = as.Date(c(
-      "2009-03-10", "2009-07-19", "2010-06-15", "2010-04-30",
-      "2008-11-27", "2008-01-29", "2010-06-12", "2010-01-15"
-    ))
-  )
-  cdm <- omopgenerics::insertTable(cdm = cdm,
-                                   name = "my_cohort",
-                                   table = cohort)
-  cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort, .softValidation = TRUE)
-  cdm$my_cohort_1 <- requireTableIntersect(cohort = cdm$my_cohort,
-                                           tableName = "measurement",
-                                           window = list(c(-Inf, 0)),
-                                           atFirst = TRUE,
-                                           name = "my_cohort_1")
-  expect_equal(
-    collectCohort(cdm$my_cohort_1, 2),
-    dplyr::tibble(
-      subject_id = 1L,
-      cohort_start_date = as.Date(NULL),
-      cohort_end_date = as.Date(NULL)
+    cdm$my_cohort <- requireTableIntersect(cdm$my_cohort, tableName = "visit_occurrence", window = list(c(-Inf, 0)))
+    expect_true(
+      DBI::dbGetQuery(con, paste0("SELECT * FROM pg_indexes WHERE tablename = 'cc_my_cohort';")) |> dplyr::pull("indexdef") ==
+        "CREATE INDEX cc_my_cohort_subject_id_cohort_start_date_idx ON public.cc_my_cohort USING btree (subject_id, cohort_start_date)"
     )
-  )
-  expect_equal(
-    attrition(cdm$my_cohort_1)$reason,
-    c('Initial qualifying events',
-      'In table measurement between -Inf & 0 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry',
-      'Initial qualifying events',
-      'In table measurement between -Inf & 0 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry'
-    ))
 
-  expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::starts_with("my_cohort"))
-  CDMConnector::cdmDisconnect(cdm = cdm)
+    # atFirst
+    cohort <- dplyr::tibble(
+      cohort_definition_id = c(rep(1L, 4), rep(2L, 4)),
+      subject_id = c(1L, 1L, 2L, 3L, rep(1L, 4)),
+      cohort_start_date = as.Date(c(
+        "2008-01-01", "2009-03-11", "2010-05-03", "2010-02-25",
+        "2008-03-24", "2008-11-28", "2010-01-30", "2009-06-13"
+      )),
+      cohort_end_date = as.Date(c(
+        "2009-03-10", "2009-07-19", "2010-06-15", "2010-04-30",
+        "2008-11-27", "2008-01-29", "2010-06-12", "2010-01-15"
+      ))
+    )
+    cdm <- omopgenerics::insertTable(cdm = cdm,
+                                     name = "my_cohort",
+                                     table = cohort)
+    cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort, .softValidation = TRUE)
+    cdm$my_cohort_1 <- requireTableIntersect(cohort = cdm$my_cohort,
+                                             tableName = "measurement",
+                                             window = list(c(-Inf, 0)),
+                                             atFirst = TRUE,
+                                             name = "my_cohort_1")
+    expect_equal(
+      collectCohort(cdm$my_cohort_1, 2),
+      dplyr::tibble(
+        subject_id = 1L,
+        cohort_start_date = as.Date(NULL),
+        cohort_end_date = as.Date(NULL)
+      )
+    )
+    expect_equal(
+      attrition(cdm$my_cohort_1)$reason,
+      c('Initial qualifying events',
+        'In table measurement between -Inf & 0 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry',
+        'Initial qualifying events',
+        'In table measurement between -Inf & 0 days relative to cohort_start_date between 1 and Inf. Requirement applied to the first entry'
+      ))
+
+    expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
+
+    dropCreatedTables(cdm = cdm)
+  }
 })
