@@ -1,5 +1,6 @@
 test_that("simple duckdb checks", {
-  testthat::skip_on_cran()
+  skip_on_cran()
+
   # create test mock ----
   cdm <- omopgenerics::cdmFromTables(
     tables = list(
@@ -37,8 +38,8 @@ test_that("simple duckdb checks", {
         ))
       )
     )
-  )
-  cdm <- cdm |> copyCdm()
+  ) |>
+    copyCdm()
 
   # test with cohort1 ----
   expect_no_error(
@@ -108,7 +109,9 @@ test_that("simple duckdb checks", {
       ) |>
       dplyr::collect() |>
       dplyr::arrange(.data$observation_period_id),
-    cdm$observation_period |> dplyr::collect() |>
+    cdm$observation_period |>
+      dplyr::collect() |>
+      dplyr::as_tibble() |>
       dplyr::arrange(.data$observation_period_id)
   )
   expect_true(
@@ -174,7 +177,6 @@ test_that("simple duckdb checks", {
     )
   )
 
-
   # check sex is consistent ----
   expect_no_error(
     cdm$obs2 <- cdm$obs |>
@@ -318,11 +320,12 @@ test_that("simple duckdb checks", {
   )
 
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  PatientProfiles::mockDisconnect(cdm)
+
+  dropCreatedTables(cdm = cdm)
 })
 
-test_that("cohort Id, name, additional columns", {
-  testthat::skip_on_cran()
+test_that("cohort Id, name, additional columns, missing year of birth", {
+  skip_on_cran()
 
   cohort_1 <- dplyr::tibble(
     cohort_definition_id = 1L,
@@ -366,25 +369,20 @@ test_that("cohort Id, name, additional columns", {
 
   person <- dplyr::tibble(
     person_id = 1:5,
-    gender_concept_id = c(8507L, 8507L, 8507L, 8532L, 8507L),
-    year_of_birth = c(1997L, 1963L, 1986L, 1978L, 1973L),
+    gender_concept_id = c(8507L, 8507L, 8507L, NA, 8507L),
+    year_of_birth = c(NA, 1963L, 1986L, 1978L, 1973L),
     month_of_birth = c(8L, 1L, 3L, 11L, 3L),
     day_of_birth = c(22L, 27L, 10L, 8L, 2L),
     race_concept_id = NA_integer_,
     ethnicity_concept_id = NA_integer_
   )
 
-  cdm_local <- omock::mockCdmFromTables(
-    tables = list(
-      "cohort1" = cohort_1,
-      "cohort2" = cohort_2
-    ),
-    seed = 1
-  )
-
-  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "observation_period", table = obs)
-  cdm_local <- omopgenerics::insertTable(cdm = cdm_local, name = "person", table = person)
-  cdm <- cdm_local |> copyCdm()
+  cdm <- omock::mockCdmFromTables(
+    tables = list("cohort1" = cohort_1, "cohort2" = cohort_2)
+  ) |>
+    omopgenerics::insertTable(name = "observation_period", table = obs) |>
+    omopgenerics::insertTable(name = "person", table = person) |>
+    copyCdm()
 
   cdm$cohort2 <- cdm$cohort2 |>
     dplyr::mutate(
@@ -395,7 +393,7 @@ test_that("cohort Id, name, additional columns", {
 
   cdm$cohort3 <- trimDemographics(cohort = cdm$cohort2,
                                   cohortId = "cohort_1",
-                                  ageRange = NULL,
+                                  ageRange = c(0, 150),
                                   sex = "Male",
                                   minPriorObservation = c(0, 400),
                                   minFutureObservation = NULL,
@@ -407,25 +405,28 @@ test_that("cohort Id, name, additional columns", {
   x1 <- collectCohort(cdm$cohort3, 1)
   x3 <- collectCohort(cdm$cohort3, 3)
   expect_identical(x1, dplyr::tibble(
-    subject_id = c(1, 1, 2, 3) |> as.integer(),
-    cohort_start_date = as.Date(c("2001-04-03", "2002-05-07", "1999-07-26", "2015-02-19")),
-    cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17", "2015-06-27"))
+    subject_id = c(2, 3) |> as.integer(),
+    cohort_start_date = as.Date(c("1999-07-26", "2015-02-19")),
+    cohort_end_date = as.Date(c("2002-09-17", "2015-06-27"))
   ))
   expect_identical(x3, dplyr::tibble(
-    subject_id = c(1, 1, 2) |> as.integer(),
-    cohort_start_date = as.Date(c("2001-07-08", "2002-05-07", "2000-05-09")),
-    cohort_end_date = as.Date(c("2002-05-06", "2005-11-07", "2002-09-17"))
+    subject_id = c(2) |> as.integer(),
+    cohort_start_date = as.Date(c("2000-05-09")),
+    cohort_end_date = as.Date(c("2002-09-17"))
   ))
   expect_true(all(
     attrition(cdm$cohort3)$reason ==
-      c('Initial qualifying events', 'Sex requirement: Male',
+      c('Initial qualifying events', "Non-missing sex", 'Sex requirement: Male',
+        "Non-missing year of birth", "Age requirement: 0 to 150" ,
         'Prior observation requirement: 0 days', 'Initial qualifying events',
-        'Initial qualifying events', 'Sex requirement: Male',
+        'Initial qualifying events', "Non-missing sex", 'Sex requirement: Male',
+        "Non-missing year of birth", "Age requirement: 0 to 150",
         'Prior observation requirement: 400 days')
   ))
   expect_identical(settings(cdm$cohort3), dplyr::tibble(
     cohort_definition_id = as.integer(1:3),
     cohort_name = c("cohort_1_1", "cohort_2", "cohort_1_2"),
+    age_range = "0_150",
     sex = c("Male", "Both", "Male"),
     min_prior_observation = c(0, 0, 400)
   ))
@@ -440,44 +441,37 @@ test_that("cohort Id, name, additional columns", {
   )
 
   expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  PatientProfiles::mockDisconnect(cdm)
+
+  dropCreatedTables(cdm = cdm)
 })
 
 test_that("test indexes - postgres", {
   skip_on_cran()
-  skip_if(Sys.getenv("CDM5_POSTGRESQL_DBNAME") == "")
   skip_if(!testIndexes)
 
-  db <- DBI::dbConnect(RPostgres::Postgres(),
-                       dbname = Sys.getenv("CDM5_POSTGRESQL_DBNAME"),
-                       host = Sys.getenv("CDM5_POSTGRESQL_HOST"),
-                       user = Sys.getenv("CDM5_POSTGRESQL_USER"),
-                       password = Sys.getenv("CDM5_POSTGRESQL_PASSWORD"))
-  cdm <- CDMConnector::cdmFromCon(
-    con = db,
-    cdmSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA"),
-    writeSchema = Sys.getenv("CDM5_POSTGRESQL_SCRATCH_SCHEMA"),
-    writePrefix = "cc_",
-    achillesSchema = Sys.getenv("CDM5_POSTGRESQL_CDM_SCHEMA")
-  )
+  if (dbToTest == "postgres CDMConnector") {
+    cdm <- omock::mockCdmFromTables(tables = list(
+      my_cohort = dplyr::tibble(
+        cohort_definition_id = 1L,
+        subject_id = 1L,
+        cohort_start_date = as.Date("2009-01-02"),
+        cohort_end_date = as.Date("2009-01-03"),
+        other_date = as.Date("2009-01-01")
+      )
+    )) |>
+      copyCdm()
 
-  cdm <- omopgenerics::insertTable(
-    cdm = cdm,
-    name = "my_cohort",
-    table = data.frame(cohort_definition_id = 1L,
-                       subject_id = 1L,
-                       cohort_start_date = as.Date("2009-01-01"),
-                       cohort_end_date = as.Date("2009-01-02"))
-  )
-  cdm$my_cohort <- omopgenerics::newCohortTable(cdm$my_cohort)
-  cdm$my_cohort <- trimDemographics(cdm$my_cohort, ageRange = list(c(0, 50)))
+    con <- CDMConnector::cdmCon(cdm = cdm)
 
-  expect_true(
-    DBI::dbGetQuery(db, paste0("SELECT * FROM pg_indexes WHERE tablename = 'cc_my_cohort';")) |> dplyr::pull("indexdef") ==
-      "CREATE INDEX cc_my_cohort_subject_id_cohort_start_date_idx ON public.cc_my_cohort USING btree (subject_id, cohort_start_date)"
-  )
+    cdm$my_cohort <- trimDemographics(cdm$my_cohort, ageRange = list(c(0, 50)))
 
-  expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
-  omopgenerics::dropSourceTable(cdm = cdm, name = dplyr::starts_with("my_cohort"))
-  CDMConnector::cdmDisconnect(cdm = cdm)
+    expect_true(
+      DBI::dbGetQuery(con, paste0("SELECT * FROM pg_indexes WHERE tablename = 'cc_my_cohort';")) |> dplyr::pull("indexdef") ==
+        "CREATE INDEX cc_my_cohort_subject_id_cohort_start_date_idx ON public.cc_my_cohort USING btree (subject_id, cohort_start_date)"
+    )
+
+    expect_true(sum(grepl("og", omopgenerics::listSourceTables(cdm))) == 0)
+
+    dropCreatedTables(cdm = cdm)
+  }
 })
